# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`restic`](#restic): Module to manage restic repositories via systemd service/timer.

#### Private Classes

* `restic::package`: Install restic packages
* `restic::reload`: Reload systemd via `systemctl daemon-reload`

### Defined types

#### Public Defined types

* [`restic::repository`](#resticrepository): Configure a Restic service to backup/forget/restore data.
* [`restic::repository::post_command`](#resticrepositorypost_command): Define command(s) to be run after a restic command
* [`restic::repository::pre_command`](#resticrepositorypre_command): Define command(s) to be run before a restic command

#### Private Defined types

* `restic::service`: Configure a restic service

### Data types

* [`Restic::Forget`](#resticforget): All valid forget parameter
* [`Restic::Path`](#resticpath): Valid path parameter
* [`Restic::Repositories`](#resticrepositories): A data hash with restic backup configuration
* [`Restic::Repository::Type`](#resticrepositorytype): All valid repository types

## Classes

### <a name="restic"></a>`restic`

Module to manage restic repositories via systemd service/timer.

#### Parameters

The following parameters are available in the `restic` class:

* [`package_ensure`](#package_ensure)
* [`package_manage`](#package_manage)
* [`package_name`](#package_name)
* [`package_version`](#package_version)
* [`checksum`](#checksum)
* [`install_method`](#install_method)
* [`repositories`](#repositories)
* [`backup_flags`](#backup_flags)
* [`backup_path`](#backup_path)
* [`backup_pre_cmd`](#backup_pre_cmd)
* [`backup_post_cmd`](#backup_post_cmd)
* [`backup_timer`](#backup_timer)
* [`binary`](#binary)
* [`bucket`](#bucket)
* [`enable_backup`](#enable_backup)
* [`enable_forget`](#enable_forget)
* [`enable_restore`](#enable_restore)
* [`forget`](#forget)
* [`forget_flags`](#forget_flags)
* [`forget_pre_cmd`](#forget_pre_cmd)
* [`forget_post_cmd`](#forget_post_cmd)
* [`forget_timer`](#forget_timer)
* [`global_flags`](#global_flags)
* [`group`](#group)
* [`host`](#host)
* [`id`](#id)
* [`init_repo`](#init_repo)
* [`key`](#key)
* [`password`](#password)
* [`prune`](#prune)
* [`restore_flags`](#restore_flags)
* [`restore_path`](#restore_path)
* [`restore_pre_cmd`](#restore_pre_cmd)
* [`restore_post_cmd`](#restore_post_cmd)
* [`restore_snapshot`](#restore_snapshot)
* [`restore_timer`](#restore_timer)
* [`type`](#type)
* [`user`](#user)

##### <a name="package_ensure"></a>`package_ensure`

Data type: `String`

Version for Restic to be installed

Default value: `'present'`

##### <a name="package_manage"></a>`package_manage`

Data type: `Boolean`

Enable Restic package management

Default value: ``true``

##### <a name="package_name"></a>`package_name`

Data type: `String`

Name for Restic package

Default value: `'restic'`

##### <a name="package_version"></a>`package_version`

Data type: `Optional[String[1]]`

Restic version when installing with the `url` method.

Default value: ``undef``

##### <a name="checksum"></a>`checksum`

Data type: `Optional[String[1]]`

Checksum of the Restic archive. Only applicable when using `install_method = 'url'`.

Default value: ``undef``

##### <a name="install_method"></a>`install_method`

Data type: `Enum['package', 'url']`

Install method to use.

Default value: `'package'`

##### <a name="repositories"></a>`repositories`

Data type: `Restic::Repositories`

Hash of repositoriries

Default value: `{}`

##### <a name="backup_flags"></a>`backup_flags`

Data type: `Variant[Array[String[1]],String[1]]`

Default flags for `restic backup <flags>`. See `restic backup --help`

Default value: `[]`

##### <a name="backup_path"></a>`backup_path`

Data type: `Optional[Restic::Path]`

Default directory to backed up

Default value: ``undef``

##### <a name="backup_pre_cmd"></a>`backup_pre_cmd`

Data type: `Optional[Variant[Array[String[1]],String[1]]]`

Default command to run before `restic backup`

Default value: ``undef``

##### <a name="backup_post_cmd"></a>`backup_post_cmd`

Data type: `Optional[Variant[Array[String[1]],String[1]]]`

Default command to run after `restic backup`

Default value: ``undef``

##### <a name="backup_timer"></a>`backup_timer`

Data type: `Optional[String[1]]`

Default systemd timer for backup see: https://wiki.archlinux.de/title/Systemd/Timers

Default value: ``undef``

##### <a name="binary"></a>`binary`

Data type: `Stdlib::Absolutepath`

Default path to the Restic binary

Default value: `'/usr/bin/restic'`

##### <a name="bucket"></a>`bucket`

Data type: `Optional[String]`

Default name for the Restic repository

Default value: ``undef``

##### <a name="enable_backup"></a>`enable_backup`

Data type: `Boolean`

Default enable the backup service

Default value: ``true``

##### <a name="enable_forget"></a>`enable_forget`

Data type: `Boolean`

Default enable the forget service

Default value: ``false``

##### <a name="enable_restore"></a>`enable_restore`

Data type: `Boolean`

Default enable the restore service

Default value: ``false``

##### <a name="forget"></a>`forget`

Data type: `Restic::Forget`

Default hash with `keep-*` => `value` to configure forget flags

Default value: `{}`

##### <a name="forget_flags"></a>`forget_flags`

Data type: `Variant[Array[String[1]],String[1]]`

Default flags for `restic forget <flags>`. See `restic forget --help`

Default value: `[]`

##### <a name="forget_pre_cmd"></a>`forget_pre_cmd`

Data type: `Optional[Variant[Array[String[1]],String[1]]]`

Default command to run before `restic forget`

Default value: ``undef``

##### <a name="forget_post_cmd"></a>`forget_post_cmd`

Data type: `Optional[Variant[Array[String[1]],String[1]]]`

Default command to run after `restic forget`

Default value: ``undef``

##### <a name="forget_timer"></a>`forget_timer`

Data type: `Optional[String[1]]`

Default systemd timer for forget see: https://wiki.archlinux.de/title/Systemd/Timers

Default value: ``undef``

##### <a name="global_flags"></a>`global_flags`

Data type: `Variant[Array[String[1]],String[1]]`

Default global flags for `restic <flags>`. See `restic --help`

Default value: `[]`

##### <a name="group"></a>`group`

Data type: `String`

Default group for systemd services

Default value: `'root'`

##### <a name="host"></a>`host`

Data type: `Optional[String]`

Default hostname for the Restic repository

Default value: ``undef``

##### <a name="id"></a>`id`

Data type: `Optional[String]`

Default S3 storage id for an S3 bucket

Default value: ``undef``

##### <a name="init_repo"></a>`init_repo`

Data type: `Boolean`

Default enable the initialization of the repository

Default value: ``true``

##### <a name="key"></a>`key`

Data type: `Optional[String]`

Default S3 storage key for an S3 bucket

Default value: ``undef``

##### <a name="password"></a>`password`

Data type: `Optional[String]`

Default encryption password for the Restic repository

Default value: ``undef``

##### <a name="prune"></a>`prune`

Data type: `Boolean`

Default enable `--prune` flag for `restic forget`

Default value: ``false``

##### <a name="restore_flags"></a>`restore_flags`

Data type: `Variant[Array[String[1]],String[1]]`

Default flags for `restic restore <flags>`. See `restic restore --help`

Default value: `[]`

##### <a name="restore_path"></a>`restore_path`

Data type: `Optional[Stdlib::Absolutepath]`

Default directory used to restore a backup

Default value: ``undef``

##### <a name="restore_pre_cmd"></a>`restore_pre_cmd`

Data type: `Optional[Variant[Array[String[1]],String[1]]]`

command to run before execute restore
Default command to run before `restic restore`

Default value: ``undef``

##### <a name="restore_post_cmd"></a>`restore_post_cmd`

Data type: `Optional[Variant[Array[String[1]],String[1]]]`

command to run after execute restore
Default command to run after `restic restore`

Default value: ``undef``

##### <a name="restore_snapshot"></a>`restore_snapshot`

Data type: `String[1]`

Default Restic snapshot id used by the restore

Default value: `'latest'`

##### <a name="restore_timer"></a>`restore_timer`

Data type: `Optional[String[1]]`

Default systemd timer for restore see: https://wiki.archlinux.de/title/Systemd/Timers

Default value: ``undef``

##### <a name="type"></a>`type`

Data type: `Restic::Repository::Type`

Default name for the Restic repository. Only S3 supported

Default value: `'s3'`

##### <a name="user"></a>`user`

Data type: `String[1]`

Default user for systemd services

Default value: `'root'`

## Defined types

### <a name="resticrepository"></a>`restic::repository`

Configure a Restic service to backup/forget/restore data.

#### Parameters

The following parameters are available in the `restic::repository` defined type:

* [`backup_flags`](#backup_flags)
* [`backup_path`](#backup_path)
* [`backup_pre_cmd`](#backup_pre_cmd)
* [`backup_post_cmd`](#backup_post_cmd)
* [`backup_timer`](#backup_timer)
* [`binary`](#binary)
* [`bucket`](#bucket)
* [`enable_backup`](#enable_backup)
* [`enable_forget`](#enable_forget)
* [`enable_restore`](#enable_restore)
* [`forget`](#forget)
* [`forget_flags`](#forget_flags)
* [`forget_pre_cmd`](#forget_pre_cmd)
* [`forget_post_cmd`](#forget_post_cmd)
* [`forget_timer`](#forget_timer)
* [`global_flags`](#global_flags)
* [`group`](#group)
* [`host`](#host)
* [`id`](#id)
* [`init_repo`](#init_repo)
* [`key`](#key)
* [`password`](#password)
* [`prune`](#prune)
* [`restore_flags`](#restore_flags)
* [`restore_path`](#restore_path)
* [`restore_pre_cmd`](#restore_pre_cmd)
* [`restore_post_cmd`](#restore_post_cmd)
* [`restore_snapshot`](#restore_snapshot)
* [`restore_timer`](#restore_timer)
* [`type`](#type)
* [`user`](#user)

##### <a name="backup_flags"></a>`backup_flags`

Data type: `Optional[Variant[Array[String[1]],String[1]]]`

Default flags for `restic backup <flags>`. See `restic backup --help`

Default value: ``undef``

##### <a name="backup_path"></a>`backup_path`

Data type: `Optional[Restic::Path]`

Default directory to backed up

Default value: ``undef``

##### <a name="backup_pre_cmd"></a>`backup_pre_cmd`

Data type: `Optional[Variant[Array[String[1]],String[1]]]`

Default command to run before `restic backup`

Default value: ``undef``

##### <a name="backup_post_cmd"></a>`backup_post_cmd`

Data type: `Optional[Variant[Array[String[1]],String[1]]]`

Default command to run after `restic backup`

Default value: ``undef``

##### <a name="backup_timer"></a>`backup_timer`

Data type: `Optional[String[1]]`

Default systemd timer for backup see: https://wiki.archlinux.de/title/Systemd/Timers

Default value: ``undef``

##### <a name="binary"></a>`binary`

Data type: `Optional[Stdlib::Absolutepath]`

Default path to the Restic binary

Default value: ``undef``

##### <a name="bucket"></a>`bucket`

Data type: `Optional[String]`

Default name for the Restic repository

Default value: ``undef``

##### <a name="enable_backup"></a>`enable_backup`

Data type: `Optional[Boolean]`

Default enable the backup service

Default value: ``undef``

##### <a name="enable_forget"></a>`enable_forget`

Data type: `Optional[Boolean]`

Default enable the forget service

Default value: ``undef``

##### <a name="enable_restore"></a>`enable_restore`

Data type: `Optional[Boolean]`

Default enable the restore service

Default value: ``undef``

##### <a name="forget"></a>`forget`

Data type: `Optional[Restic::Forget]`

Default hash with `keep-*` => `value` to configure forget flags

Default value: ``undef``

##### <a name="forget_flags"></a>`forget_flags`

Data type: `Optional[Variant[Array[String[1]],String[1]]]`

Default flags for `restic forget <flags>`. See `restic forget --help`

Default value: ``undef``

##### <a name="forget_pre_cmd"></a>`forget_pre_cmd`

Data type: `Optional[Variant[Array[String[1]],String[1]]]`

Default command to run before `restic forget`

Default value: ``undef``

##### <a name="forget_post_cmd"></a>`forget_post_cmd`

Data type: `Optional[Variant[Array[String[1]],String[1]]]`

Default command to run after `restic forget`

Default value: ``undef``

##### <a name="forget_timer"></a>`forget_timer`

Data type: `Optional[String[1]]`

Default systemd timer for forget see: https://wiki.archlinux.de/title/Systemd/Timers

Default value: ``undef``

##### <a name="global_flags"></a>`global_flags`

Data type: `Optional[Variant[Array[String[1]],String[1]]]`

Default global flags for `restic <flags>`. See `restic --help`

Default value: ``undef``

##### <a name="group"></a>`group`

Data type: `Optional[String]`

Default group for systemd services

Default value: ``undef``

##### <a name="host"></a>`host`

Data type: `Optional[String]`

Default hostname for the Restic repository

Default value: ``undef``

##### <a name="id"></a>`id`

Data type: `Optional[String]`

Default S3 storage id for an S3 bucket

Default value: ``undef``

##### <a name="init_repo"></a>`init_repo`

Data type: `Optional[Boolean]`

Default enable the initialization of the repository

Default value: ``undef``

##### <a name="key"></a>`key`

Data type: `Optional[String]`

Default S3 storage key for an S3 bucket

Default value: ``undef``

##### <a name="password"></a>`password`

Data type: `Optional[String]`

Default encryption password for the Restic repository

Default value: ``undef``

##### <a name="prune"></a>`prune`

Data type: `Optional[Boolean]`

Default enable `--prune` flag for `restic forget`

Default value: ``undef``

##### <a name="restore_flags"></a>`restore_flags`

Data type: `Optional[Variant[Array[String[1]],String[1]]]`

Default flags for `restic restore <flags>`. See `restic restore --help`

Default value: ``undef``

##### <a name="restore_path"></a>`restore_path`

Data type: `Optional[Stdlib::Absolutepath]`

Default directory used to restore a backup

Default value: ``undef``

##### <a name="restore_pre_cmd"></a>`restore_pre_cmd`

Data type: `Optional[Variant[Array[String[1]],String[1]]]`

command to run before execute restore
Default command to run before `restic restore`

Default value: ``undef``

##### <a name="restore_post_cmd"></a>`restore_post_cmd`

Data type: `Optional[Variant[Array[String[1]],String[1]]]`

command to run after execute restore
Default command to run after `restic restore`

Default value: ``undef``

##### <a name="restore_snapshot"></a>`restore_snapshot`

Data type: `Optional[String[1]]`

Default Restic snapshot id used by the restore

Default value: ``undef``

##### <a name="restore_timer"></a>`restore_timer`

Data type: `Optional[String[1]]`

Default systemd timer for restore see: https://wiki.archlinux.de/title/Systemd/Timers

Default value: ``undef``

##### <a name="type"></a>`type`

Data type: `Optional[Restic::Repository::Type]`

Default name for the Restic repository. Only S3 supported

Default value: ``undef``

##### <a name="user"></a>`user`

Data type: `Optional[String[1]]`

Default user for systemd services

Default value: ``undef``

### <a name="resticrepositorypost_command"></a>`restic::repository::post_command`

Define command(s) to be run after a restic command

#### Examples

##### Define a command to be run after the backup

```puppet
restic::repository::pre_command { 'mysql':
  command => 'rm -rf /opt/xtrabackup',
}
```

#### Parameters

The following parameters are available in the `restic::repository::post_command` defined type:

* [`command`](#command)
* [`repository_title`](#repository_title)
* [`restic_command`](#restic_command)
* [`allow_fail`](#allow_fail)
* [`order`](#order)

##### <a name="command"></a>`command`

Data type: `Variant[Array[String[1]],String[1]]`

Command to run.

##### <a name="repository_title"></a>`repository_title`

Data type: `String[1]`

restic::repository title where this command should be add to.

Default value: `$title`

##### <a name="restic_command"></a>`restic_command`

Data type: `Enum['backup', 'forget', 'restore']`

After which restic command this command should be run.

Default value: `'backup'`

##### <a name="allow_fail"></a>`allow_fail`

Data type: `Boolean`

If an error of this commands should be allowed.

Default value: ``false``

##### <a name="order"></a>`order`

Data type: `Integer[26]`

Order of Commands. Helpful if you have multiple.

Default value: `26`

### <a name="resticrepositorypre_command"></a>`restic::repository::pre_command`

Define command(s) to be run before a restic command

#### Examples

##### Define a command to be run before the backup

```puppet
restic::repository::pre_command { 'mysql':
  command => 'xtrabackup --backup --target-dir=/opt/xtrabackup',
}
```

#### Parameters

The following parameters are available in the `restic::repository::pre_command` defined type:

* [`command`](#command)
* [`repository_title`](#repository_title)
* [`restic_command`](#restic_command)
* [`allow_fail`](#allow_fail)
* [`order`](#order)

##### <a name="command"></a>`command`

Data type: `Variant[Array[String[1]],String[1]]`

Command to run.

##### <a name="repository_title"></a>`repository_title`

Data type: `String[1]`

restic::repository title where this command should be add to.

Default value: `$title`

##### <a name="restic_command"></a>`restic_command`

Data type: `Enum['backup', 'forget', 'restore']`

Before which restic command this command should be run.

Default value: `'backup'`

##### <a name="allow_fail"></a>`allow_fail`

Data type: `Boolean`

If an error of this commands should be allowed.

Default value: ``false``

##### <a name="order"></a>`order`

Data type: `Integer[11,24]`

Order of Commands. Helpful if you have multiple.

Default value: `11`

## Data types

### <a name="resticforget"></a>`Restic::Forget`

All valid forget parameter

Alias of

```puppet
Hash[Enum['keep-last','keep-hourly','keep-daily','keep-weekly','keep-monthly','keep-yearly','keep-within','keep-tag'], Integer[1]]
```

### <a name="resticpath"></a>`Restic::Path`

Valid path parameter

Alias of

```puppet
Variant[Stdlib::Absolutepath, Array[Stdlib::Absolutepath]]
```

### <a name="resticrepositories"></a>`Restic::Repositories`

A data hash with restic backup configuration

Alias of

```puppet
Hash[String[1], Struct[
    {
      backup_flags     => Optional[Variant[Array[String[1]],String[1]]],
      backup_path      => Optional[Restic::Path],
      backup_post_cmd  => Optional[String[1]],
      backup_pre_cmd   => Optional[String[1]],
      backup_timer     => Optional[String[1]],
      binary           => Optional[Stdlib::Absolutepath],
      bucket           => Optional[String[1]],
      check            => Optional[Boolean],
      enable_backup    => Optional[Boolean],
      enable_forget    => Optional[Boolean],
      enable_restore   => Optional[Boolean],
      forget           => Optional[Restic::Forget],
      forget_flags     => Optional[Variant[Array[String[1]],String[1]]],
      forget_post_cmd  => Optional[String[1]],
      forget_pre_cmd   => Optional[String[1]],
      forget_timer     => Optional[String[1]],
      global_flags     => Optional[Variant[Array[String[1]],String[1]]],
      group            => Optional[String[1]],
      host             => Optional[String[1]],
      id               => Optional[String[1]],
      init_repo        => Optional[Boolean],
      key              => Optional[String[1]],
      password         => Optional[String[1]],
      prune            => Optional[Boolean],
      restore_flags    => Optional[Variant[Array[String[1]],String[1]]],
      restore_path     => Optional[Stdlib::Absolutepath],
      restore_post_cmd => Optional[String[1]],
      restore_pre_cmd  => Optional[String[1]],
      restore_snapshot => Optional[String[1]],
      restore_timer    => Optional[String[1]],
      type             => Optional[Restic::Repository::Type],
      user             => Optional[String[1]],
    }
  ]]
```

### <a name="resticrepositorytype"></a>`Restic::Repository::Type`

All valid repository types

Alias of

```puppet
Enum['rest', 's3']
```

